From 67e5925897144effb8f4a9404bd2c5b25aa1aa4f Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Wed, 08 Feb 2012 04:06:59 -0500
Subject: [PATCH] - Handle HTML entities properly when converting strong/b/th content to upper case

---
 program/lib/html2text.php |   16 +++++++++++-----
 1 files changed, 11 insertions(+), 5 deletions(-)

diff --git a/program/lib/html2text.php b/program/lib/html2text.php
index 9fc96ea..0171f4b 100644
--- a/program/lib/html2text.php
+++ b/program/lib/html2text.php
@@ -699,16 +699,22 @@
     }
 
     /**
      *  Strtoupper multibyte wrapper function
      *
-     *  @param  string
-     *  @return string
+     *  @param string $str Text to convert
+     *  @return string Converted text
      */
     private function _strtoupper($str)
     {
+        $str = html_entity_decode($str, ENT_COMPAT, RCMAIL_CHARSET);
+
         if (function_exists('mb_strtoupper'))
-            return mb_strtoupper($str);
+            $str = mb_strtoupper($str);
         else
-            return strtoupper($str);
+            $str = strtoupper($str);
+
+        $str = htmlspecialchars($str, ENT_COMPAT, RCMAIL_CHARSET);
+
+        return $str;
     }
 }
@@ -699,16 +699,22 @@
 
     /**
-     *  Strtoupper multibyte wrapper function
+     *  Strtoupper multibyte wrapper function with HTML entities handling
      *

--
Gitblit v1.9.1